@@ -13,18 +13,19 @@ def replace_spaces(string):
     """
     return string.replace(" ", ".")
 
-def profile_search(search):
+def profile_search(search, remote_url="http://51.83.33.219:4432"):
     """
-    It takes a search term as an argument, opens a browser, goes to the quora search page, scrapes the
-    usernames and urls of the results, and returns a dictionary with the usernames and urls
+    It opens a browser, goes to the quora search page, finds the elements with the class name "q-box
+    qu-color--blue_dark qu-cursor--pointer qu-hover--textDecoration--underline Link___StyledBox-t2xg9c-0
+    dxHfBI" and "q-text qu-bold", and returns the urls and usernames of the profiles
     
     :param search: The search term you want to search for
-    :return: A dictionary of questions and their urls
+    :return: A list of usernames, a list of urls, and a dictionary of profiles.
     """
     try:
         # Opening a browser and going to the quora search page.
         chrome_options = webdriver.ChromeOptions()
-        driver = webdriver.Remote(command_executor='http://51.83.33.219:4432', options=chrome_options)
+        driver = webdriver.Remote(command_executor=remote_url, options=chrome_options)
         url = f"https://www.quora.com/search?q={search}&type=profile"
         driver.get(url)
         time.sleep(2)
@@ -45,6 +46,7 @@ def profile_search(search):
         driver.quit()
         logging.info(f"Search on quora for {search} has been done")
         return usernames, urls, profiles_dict
+    
     except Exception as e:
         logging.error(f"Search on quora for {search} has failed")
         driver.quit()
